@@ -7,11 +7,22 @@
 #include <rem.h>
 #include <baresip.h>
 #include <libavcodec/avcodec.h>
+#include <libavutil/avutil.h>
 #include <libavutil/mem.h>
+#if LIBAVCODEC_VERSION_INT >= ((53<<16)+(5<<8)+0)
+#include <libavutil/pixdesc.h>
+#endif
 #include "h26x.h"
 #include "avcodec.h"
 
 
+#if LIBAVUTIL_VERSION_MAJOR < 52
+#define AV_PIX_FMT_YUV420P PIX_FMT_YUV420P
+#define AV_PIX_FMT_YUVJ420P PIX_FMT_YUVJ420P
+#define AV_PIX_FMT_NV12    PIX_FMT_NV12
+#endif
+
+
 struct viddec_state {
 	AVCodec *codec;
 	AVCodecContext *ctx;
@@ -167,13 +178,32 @@ static int ffdecode(struct viddec_state *st, struct vidframe *frame,
 	mbuf_skip_to_end(src);
 
 	if (got_picture) {
+
+#if LIBAVCODEC_VERSION_INT >= ((53<<16)+(5<<8)+0)
+		switch (st->pict->format) {
+
+		case AV_PIX_FMT_YUV420P:
+		case AV_PIX_FMT_YUVJ420P:
+			frame->fmt = VID_FMT_YUV420P;
+			break;
+
+		default:
+			warning("avcodec: decode: bad pixel format"
+				" (%i) (%s)\n",
+				st->pict->format,
+				av_get_pix_fmt_name(st->pict->format));
+			goto out;
+		}
+#else
+		frame->fmt = VID_FMT_YUV420P;
+#endif
+
 		for (i=0; i<4; i++) {
 			frame->data[i]     = st->pict->data[i];
 			frame->linesize[i] = st->pict->linesize[i];
 		}
 		frame->size.w = st->ctx->width;
 		frame->size.h = st->ctx->height;
-		frame->fmt    = VID_FMT_YUV420P;
 	}
 
  out:
