@@ -35,11 +35,13 @@ static struct le *le_cur;             /**< Current User-Agent (struct ua) */
 
 static struct {
 	struct play *play;
+	bool bell;
 } menu;
 
 
 static void menu_set_incall(bool incall);
 static void update_callstatus(void);
+static void alert_stop(void);
 
 
 static const char *translate_errorcode(uint16_t scode)
@@ -89,13 +91,7 @@ static void check_registrations(void)
  */
 static struct ua *uag_cur(void)
 {
-	if (list_isempty(uag_list()))
-		return NULL;
-
-	if (!le_cur)
-		le_cur = list_head(uag_list());
-
-	return list_ledata(le_cur);
+	return uag_current();
 }
 
 
@@ -305,15 +301,18 @@ static int options_command(struct re_printf *pf, void *arg)
 
 static int cmd_answer(struct re_printf *pf, void *unused)
 {
-	(void)pf;
+	struct ua *ua = uag_cur();
+	int err;
 	(void)unused;
 
+	err = re_hprintf(pf, "%s: Answering incoming call\n", ua_aor(ua));
+
 	/* Stop any ongoing ring-tones */
 	menu.play = mem_deref(menu.play);
 
-	ua_hold_answer(uag_cur(), NULL);
+	ua_hold_answer(ua, NULL);
 
-	return 0;
+	return err;
 }
 
 
@@ -324,6 +323,7 @@ static int cmd_hangup(struct re_printf *pf, void *unused)
 
 	/* Stop any ongoing ring-tones */
 	menu.play = mem_deref(menu.play);
+	alert_stop();
 
 	ua_hangup(uag_cur(), NULL, 0, NULL);
 
@@ -535,11 +535,100 @@ static int call_holdresume(struct re_printf *pf, void *arg)
 }
 
 
-static int hold_prev_call(struct re_printf *pf, void *unused)
+static int hold_prev_call(struct re_printf *pf, void *arg)
 {
+	const struct cmd_arg *carg = arg;
 	(void)pf;
-	(void)unused;
-	return call_hold(ua_prev_call(uag_cur()), true);
+
+	return call_hold(ua_prev_call(uag_cur()), 'H' == carg->key);
+}
+
+
+static int switch_audio_dev(struct re_printf *pf, void *arg)
+{
+	const struct cmd_arg *carg = arg;
+	struct pl pl_driver, pl_device;
+	struct config_audio *aucfg;
+	struct config *cfg;
+	struct audio *a;
+	struct le *le;
+	char driver[16], device[128] = "";
+	int err = 0;
+
+	static bool switch_aud_inprogress;
+
+	if (!switch_aud_inprogress && !carg->complete) {
+		re_hprintf(pf,
+			   "\rPlease enter audio device (driver,device)\n");
+	}
+
+	switch_aud_inprogress = true;
+
+	if (carg->complete) {
+
+		switch_aud_inprogress = false;
+
+		if (re_regex(carg->prm, str_len(carg->prm), "[^,]+,[~]*",
+			     &pl_driver, &pl_device)) {
+
+			return re_hprintf(pf, "\rFormat should be:"
+					  " driver,device\n");
+		}
+
+		pl_strcpy(&pl_driver, driver, sizeof(driver));
+		pl_strcpy(&pl_device, device, sizeof(device));
+
+		if (!ausrc_find(driver)) {
+			re_hprintf(pf, "no such audio-source: %s\n", driver);
+			return 0;
+		}
+		if (!auplay_find(driver)) {
+			re_hprintf(pf, "no such audio-player: %s\n", driver);
+			return 0;
+		}
+
+		re_hprintf(pf, "switch audio device: %s,%s\n",
+			   driver, device);
+
+		for (le = list_tail(ua_calls(uag_cur())); le; le = le->prev) {
+
+			struct call *call = le->data;
+
+			a = call_audio(call);
+
+			err = audio_set_player(a, driver, device);
+			if (err) {
+				re_hprintf(pf, "failed to set audio-player"
+					   " (%m)\n", err);
+				break;
+			}
+
+			err = audio_set_source(a, driver, device);
+			if (err) {
+				re_hprintf(pf, "failed to set audio-source"
+					   " (%m)\n", err);
+				break;
+			}
+		}
+
+		cfg = conf_config();
+		if (!cfg) {
+			return re_hprintf(pf, "no config object\n");
+		}
+
+		aucfg = &cfg->audio;
+
+		str_ncpy(aucfg->play_mod, driver, sizeof(aucfg->play_mod));
+		str_ncpy(aucfg->play_dev, device, sizeof(aucfg->play_dev));
+
+		str_ncpy(aucfg->src_mod, driver, sizeof(aucfg->src_mod));
+		str_ncpy(aucfg->src_dev, device, sizeof(aucfg->src_dev));
+
+		str_ncpy(aucfg->alert_mod, driver, sizeof(aucfg->alert_mod));
+		str_ncpy(aucfg->alert_dev, device, sizeof(aucfg->alert_dev));
+	}
+
+	return 0;
 }
 
 
@@ -600,6 +689,8 @@ static const struct cmd callcmdv[] = {
 	{'r', CMD_IPRM,"Transfer call",       call_xfer             },
 	{'x',       0, "Call hold",           call_holdresume       },
 	{'H',       0, "Hold previous call",  hold_prev_call        },
+	{'L',       0, "Resume previous call",hold_prev_call        },
+	{'A', CMD_IPRM,"Switch audio device", switch_audio_dev      },
 
 #ifdef USE_VIDEO
 	{'E',       0, "Cycle video encoder", call_videoenc_cycle   },
@@ -671,6 +762,9 @@ static void alert_start(void *arg)
 {
 	(void)arg;
 
+	if (!menu.bell)
+		return;
+
 	ui_output("\033[10;1000]\033[11;1000]\a");
 
 	tmr_start(&tmr_alert, 1000, alert_start, NULL);
@@ -679,6 +773,9 @@ static void alert_start(void *arg)
 
 static void alert_stop(void)
 {
+	if (!menu.bell)
+		return;
+
 	if (tmr_isrunning(&tmr_alert))
 		ui_output("\r");
 
@@ -696,6 +793,10 @@ static void ua_event_handler(struct ua *ua, enum ua_event ev,
 	switch (ev) {
 
 	case UA_EVENT_CALL_INCOMING:
+
+		/* set the current User-Agent to the one with the call */
+		uag_current_set(ua);
+
 		info("%s: Incoming call from: %s %s -"
 		     " (press ENTER to accept)\n",
 		     ua_aor(ua), call_peername(call), call_peeruri(call));
@@ -717,8 +818,9 @@ static void ua_event_handler(struct ua *ua, enum ua_event ev,
 				(void)play_file(&menu.play, "ring.wav", -1);
 			}
 
+			if (menu.bell)
+				alert_start(0);
 		}
-		alert_start(0);
 		break;
 
 	case UA_EVENT_CALL_RINGING:
@@ -782,6 +884,8 @@ static int module_init(void)
 {
 	int err;
 
+	conf_get_bool(conf_cur(), "menu_bell", &menu.bell);
+
 	dialbuf = mbuf_alloc(64);
 	if (!dialbuf)
 		return ENOMEM;
