@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2010 Creytiv.com
  */
+#define _DEFAULT_SOURCE 1
 #define _BSD_SOURCE 1
 #include <unistd.h>
 #include <stdlib.h>
@@ -19,6 +20,13 @@
 #include <baresip.h>
 
 
+/**
+ * @defgroup v4l v4l
+ *
+ * Video4Linux video-source module
+ */
+
+
 struct vidsrc_st {
 	const struct vidsrc *vs;  /* inheritance */
 
